==> basicsynbio-0.6.0.tar.gz: basicsynbio-0.6.0/README.md <==
# basicsynbio

An open-source Python package to facilitate BASIC DNA assembly workflows. Also available as a [web-app][webapp_url]!

[![Build Status][ci_badge]][ci_url]
[![Coverage Status][coverage_badge]][coverage_url]
[![pypi badge][pypi_badge]][pypi_url]
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

## Installation

Using a python environment running python version >= 3.8:

```shell
$ pip install basicsynbio
```

## Usage

Refer to the [section of the documentation of usage](https://londonbiofoundry.github.io/basicsynbio/usage.html).

## Contributing

Refer to the [section of the documentation on contributing](https://londonbiofoundry.github.io/basicsynbio/contributing.html).

## Meta

This project is licensed under the BSD 3-Clause License - see the ``LICENSE`` file for details

[ci_badge]: https://github.com/LondonBiofoundry/basicsynbio/actions/workflows/main.yml/badge.svg
[ci_url]: https://github.com/LondonBiofoundry/basicsynbio/actions/workflows/main.yml
[pypi_badge]: https://img.shields.io/pypi/v/basicsynbio.svg
[pypi_url]: https://pypi.python.org/pypi/basicsynbio
[coverage_badge]: https://coveralls.io/repos/github/LondonBiofoundry/basicsynbio/badge.svg?branch=master
[coverage_url]: https://coveralls.io/github/LondonBiofoundry/basicsynbio?branch=master
[development_url]: https://packaging.python.org/guides/distributing-packages-using-setuptools/#working-in-development-mode
[webapp_url]: https://basicsynbio.web.app/designer

==> basicsynbio-0.8.0.tar.gz: basicsynbio-0.8.0/README.md <==
# basicsynbio

An open-source Python package to facilitate BASIC DNA assembly workflows. Also available as a [web-app][webapp_url]!

[![Build Status][ci_badge]][ci_url]
[![Coverage Status][coverage_badge]][coverage_url]
[![pypi badge][pypi_badge]][pypi_url]
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

## Installation

Using a python environment running python version >= 3.8:

```shell
$ pip install basicsynbio
```

## Usage

Refer to the [section of the documentation of usage](https://londonbiofoundry.github.io/basicsynbio/usage.html).

## Contributing

Refer to the [section of the documentation on contributing](https://londonbiofoundry.github.io/basicsynbio/contributing.html).

## Meta

This project is licensed under the BSD 3-Clause License - see the ``LICENSE`` file for details

[ci_badge]: https://github.com/LondonBiofoundry/basicsynbio/actions/workflows/push.yml/badge.svg
[ci_url]: https://github.com/LondonBiofoundry/basicsynbio/actions/workflows/push.yml
[pypi_badge]: https://img.shields.io/pypi/v/basicsynbio.svg
[pypi_url]: https://pypi.python.org/pypi/basicsynbio
[coverage_badge]: https://coveralls.io/repos/github/LondonBiofoundry/basicsynbio/badge.svg?branch=master
[coverage_url]: https://coveralls.io/github/LondonBiofoundry/basicsynbio?branch=master
[development_url]: https://packaging.python.org/guides/distributing-packages-using-setuptools/#working-in-development-mode
[webapp_url]: https://basicsynbio.web.app/designer
